#
# Copyright:: Copyright (c) 2012 Opscode, Inc.
# License:: Apache License, Version 2.0
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

postgresql_dir = node['chef_server']['postgresql']['dir']
postgresql_data_dir = node['chef_server']['postgresql']['data_dir']
#postgresql_data_dir_symlink = File.join(postgresql_dir, "data")
postgresql_log_dir = node['chef_server']['postgresql']['log_directory']
chef_db_dir = Dir.glob("/opt/chef-server/embedded/service/erchef/lib/chef_db-*").first

user node['chef_server']['postgresql']['username'] do
  system true
  shell node['chef_server']['postgresql']['shell']
  home node['chef_server']['postgresql']['home']
end

directory postgresql_log_dir do
  owner node['chef_server']['postgresql']['username']
  group "postgres"
  recursive true
end

directory postgresql_dir do
  owner node['chef_server']['postgresql']['username']
  group "postgres"
  mode "0700"
end

directory postgresql_data_dir do
  owner node['chef_server']['postgresql']['username']
  group "postgres"
  mode "0700"
  recursive true
end

#link postgresql_data_dir_symlink do
#  to postgresql_data_dir
#  not_if { postgresql_data_dir == postgresql_data_dir_symlink }
#end

file File.join(node['chef_server']['postgresql']['home'], ".profile") do
  owner node['chef_server']['postgresql']['username']
  group "postgres"
  mode "0644"
  content <<-EOH
PATH=#{node['chef_server']['postgresql']['user_path']}
EOH
end

if File.directory?("/etc/sysctl.d") && File.exists?("/etc/init.d/procps")
  # smells like ubuntu...
  service "procps" do
    action :nothing
  end

  template "/etc/sysctl.d/90-postgresql.conf" do
    source "90-postgresql.conf.sysctl.erb"
    owner "root"
    mode  "0644"
    variables(node['chef_server']['postgresql'].to_hash)
    notifies :start, 'service[procps]', :immediately
  end
else
  # hope this works...
  execute "sysctl" do
    command "/sbin/sysctl -p /etc/sysctl.conf"
    action :nothing
  end

  bash "add shm settings" do
    user "root"
    code <<-EOF
      echo 'kernel.shmmax = #{node['chef_server']['postgresql']['shmmax']}' >> /etc/sysctl.conf
      echo 'kernel.shmall = #{node['chef_server']['postgresql']['shmall']}' >> /etc/sysctl.conf
    EOF
    notifies :run, 'execute[sysctl]', :immediately
    not_if "egrep '^kernel.shmmax = ' /etc/sysctl.conf"
  end
end

execute "/usr/bin/initdb -D #{postgresql_data_dir}" do
  user node['chef_server']['postgresql']['username']
  group "postgres"
  not_if { File.exists?(File.join(postgresql_data_dir, "PG_VERSION")) }
end

postgresql_config = File.join(postgresql_data_dir, "postgresql.conf")

template postgresql_config do
  source "postgresql.conf.erb"
  owner node['chef_server']['postgresql']['username']
  group "postgres"
  mode "0644"
  variables(node['chef_server']['postgresql'].to_hash)
  notifies :restart, 'service[postgresql]' if OmnibusHelper.should_notify?("postgresql")
end

pg_hba_config = File.join(postgresql_data_dir, "pg_hba.conf")

template pg_hba_config do
  source "pg_hba.conf.erb"
  owner node['chef_server']['postgresql']['username']
  group "postgres"
  mode "0644"
  variables(node['chef_server']['postgresql'].to_hash)
  notifies :restart, 'service[postgresql]' if OmnibusHelper.should_notify?("postgresql")
end

should_notify = OmnibusHelper.should_notify?("postgresql")

#runit_service "postgresql" do
#  down node['chef_server']['postgresql']['ha']
#  control(['t'])
#  options({
#    :log_directory => postgresql_log_dir,
#    :svlogd_size => node['chef_server']['postgresql']['svlogd_size'],
#    :svlogd_num  => node['chef_server']['postgresql']['svlogd_num']
#  }.merge(params))
#end

service "postgresql" do
  supports :status => true, :start => true, :stop => true, :restart => true
  action [ :enable, :restart ]
end

if node['chef_server']['bootstrap']['enable']
  execute "/usr/bin/chef-server-ctl start postgresql" do
    retries 20
  end
end

###
# Create the database, migrate it, and create the users we need, and grant them
# privileges.
###
database_exists = "/usr/bin/sudo -u #{node['chef_server']['postgresql']['username']} /usr/bin/psql -d 'template1' -c 'select datname from pg_database' -x|grep opscode_chef"
user_exists     = "/usr/bin/sudo -u #{node['chef_server']['postgresql']['username']} /usr/bin/psql -d 'template1' -c 'select usename from pg_user' -x|grep #{node['chef_server']['postgresql']['sql_user']}"
ro_user_exists  = "/usr/bin/sudo -u #{node['chef_server']['postgresql']['username']} /usr/bin/psql -d 'template1' -c 'select usename from pg_user' -x|grep #{node['chef_server']['postgresql']['sql_ro_user']}"

execute "/usr/bin/createdb -T template0 -E UTF-8 opscode_chef" do
  user node['chef_server']['postgresql']['username']
  not_if database_exists
  retries 30
  notifies :run, "execute[migrate_database]", :immediately
end

execute "migrate_database" do
  command "/usr/bin/psql opscode_chef < priv/pgsql_schema.sql"
  cwd chef_db_dir
  user node['chef_server']['postgresql']['username']
  action :nothing
end

execute "/usr/bin/psql -d 'opscode_chef' -c \"CREATE USER #{node['chef_server']['postgresql']['sql_user']} WITH SUPERUSER ENCRYPTED PASSWORD '#{node['chef_server']['postgresql']['sql_password']}'\"" do
  cwd chef_db_dir
  user node['chef_server']['postgresql']['username']
  notifies :run, "execute[grant opscode_chef privileges]", :immediately
  not_if user_exists
end

execute "grant opscode_chef privileges" do
  command "/usr/bin/psql -d 'opscode_chef' -c \"GRANT ALL PRIVILEGES ON DATABASE opscode_chef TO #{node['chef_server']['postgresql']['sql_user']}\""
  user node['chef_server']['postgresql']['username']
  action :nothing
end

execute "/usr/bin/psql -d 'opscode_chef' -c \"CREATE USER #{node['chef_server']['postgresql']['sql_ro_user']} WITH SUPERUSER ENCRYPTED PASSWORD '#{node['chef_server']['postgresql']['sql_ro_password']}'\"" do
  cwd chef_db_dir
  user node['chef_server']['postgresql']['username']
  notifies :run, "execute[grant opscode_chef_ro privileges]", :immediately
  not_if ro_user_exists
end

execute "grant opscode_chef_ro privileges" do
  command "/usr/bin/psql -d 'opscode_chef' -c \"GRANT ALL PRIVILEGES ON DATABASE opscode_chef TO #{node['chef_server']['postgresql']['sql_ro_user']}\""
  user node['chef_server']['postgresql']['username']
  action :nothing
end
